summaryrefslogtreecommitdiffstats
path: root/kcontrol/crypto
diff options
context:
space:
mode:
Diffstat (limited to 'kcontrol/crypto')
-rw-r--r--kcontrol/crypto/certgen.ui66
-rw-r--r--kcontrol/crypto/crypto.cpp42
2 files changed, 54 insertions, 54 deletions
diff --git a/kcontrol/crypto/certgen.ui b/kcontrol/crypto/certgen.ui
index 19ee05535..cbffdf872 100644
--- a/kcontrol/crypto/certgen.ui
+++ b/kcontrol/crypto/certgen.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>D_GenCert</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>0</x>
<y>0</y>
@@ -19,7 +19,7 @@
<property name="name">
<cstring>TextLabel2</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>10</x>
<y>40</y>
@@ -41,7 +41,7 @@
<property name="name">
<cstring>TextLabel3</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>10</x>
<y>100</y>
@@ -57,7 +57,7 @@
<property name="name">
<cstring>TextLabel4</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>10</x>
<y>130</y>
@@ -73,7 +73,7 @@
<property name="name">
<cstring>T_CertType</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>10</x>
<y>10</y>
@@ -89,7 +89,7 @@
<property name="name">
<cstring>TextLabel2_2</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>10</x>
<y>70</y>
@@ -105,7 +105,7 @@
<property name="name">
<cstring>TextLabel5</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>10</x>
<y>160</y>
@@ -121,7 +121,7 @@
<property name="name">
<cstring>TextLabel6</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>10</x>
<y>190</y>
@@ -137,7 +137,7 @@
<property name="name">
<cstring>TextLabel7</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>10</x>
<y>220</y>
@@ -153,7 +153,7 @@
<property name="name">
<cstring>TextLabel8</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>10</x>
<y>250</y>
@@ -169,7 +169,7 @@
<property name="name">
<cstring>L_CertType</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>180</x>
<y>10</y>
@@ -182,7 +182,7 @@
<property name="name">
<cstring>LineEdit3</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>180</x>
<y>100</y>
@@ -198,7 +198,7 @@
<property name="name">
<cstring>TextLabel9</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>10</x>
<y>280</y>
@@ -214,7 +214,7 @@
<property name="name">
<cstring>LineEdit4_2_2_2</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>180</x>
<y>220</y>
@@ -230,7 +230,7 @@
<property name="name">
<cstring>LineEdit4_2_2_2_2</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>180</x>
<y>250</y>
@@ -246,7 +246,7 @@
<property name="name">
<cstring>LineEdit4_2_2_2_3</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>180</x>
<y>280</y>
@@ -262,7 +262,7 @@
<property name="name">
<cstring>E_Passphrase</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>180</x>
<y>40</y>
@@ -281,7 +281,7 @@
<property name="name">
<cstring>E_Passphrase_2</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>180</x>
<y>70</y>
@@ -300,7 +300,7 @@
<property name="name">
<cstring>TextLabel10</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>10</x>
<y>310</y>
@@ -316,7 +316,7 @@
<property name="name">
<cstring>SpinBox1</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>180</x>
<y>310</y>
@@ -338,7 +338,7 @@
<property name="name">
<cstring>TextLabel11</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>320</x>
<y>40</y>
@@ -354,7 +354,7 @@
<property name="name">
<cstring>CheckBox1</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>320</x>
<y>10</y>
@@ -373,7 +373,7 @@
<property name="name">
<cstring>TextLabel12</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>320</x>
<y>70</y>
@@ -389,7 +389,7 @@
<property name="name">
<cstring>LineEdit19</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>380</x>
<y>70</y>
@@ -402,7 +402,7 @@
<property name="name">
<cstring>LineEdit4_2_2</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>180</x>
<y>190</y>
@@ -418,7 +418,7 @@
<property name="name">
<cstring>LineEdit4_2</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>180</x>
<y>160</y>
@@ -434,7 +434,7 @@
<property name="name">
<cstring>ComboBox2</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>380</x>
<y>40</y>
@@ -447,7 +447,7 @@
<property name="name">
<cstring>CheckBox2</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>320</x>
<y>100</y>
@@ -463,7 +463,7 @@
<property name="name">
<cstring>TextLabel13</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>320</x>
<y>130</y>
@@ -479,7 +479,7 @@
<property name="name">
<cstring>ComboBox5</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>400</x>
<y>130</y>
@@ -492,7 +492,7 @@
<property name="name">
<cstring>LineEdit4</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>180</x>
<y>130</y>
@@ -508,6 +508,6 @@
<includes>
<include location="local" impldecl="in implementation">kdialog.h</include>
</includes>
-<layoutdefaults spacing="3" margin="6"/>
-<layoutfunctions spacing="KDialog::spacingHint" margin="KDialog::marginHint"/>
+<tqlayoutdefaults spacing="3" margin="6"/>
+<tqlayoutfunctions spacing="KDialog::spacingHint" margin="KDialog::marginHint"/>
</UI>
diff --git a/kcontrol/crypto/crypto.cpp b/kcontrol/crypto/crypto.cpp
index d39c09752..4194fdaec 100644
--- a/kcontrol/crypto/crypto.cpp
+++ b/kcontrol/crypto/crypto.cpp
@@ -128,7 +128,7 @@ OtherCertItem::OtherCertItem( TQListView *view, const TQString& sub, const TQStr
m_module = module;
KSSLX509Map cert(sub);
setText(0, cert.getValue("O"));
- setText(1, cert.getValue("CN").replace("\n", ", "));
+ setText(1, cert.getValue("CN").tqreplace("\n", ", "));
if (_exp.date().year() > 3000 || _exp.date().year() < 1900)
_exp.setDate(TQDate(3000,1,1));
@@ -151,7 +151,7 @@ YourCertItem::YourCertItem( TQListView *view, TQString pkcs, TQString pass, TQSt
{
m_module = module;
KSSLX509Map cert(name);
- TQString tmp = cert.getValue("CN").replace("\n", ", ");
+ TQString tmp = cert.getValue("CN").tqreplace("\n", ", ");
setText(0, tmp);
setText(1, cert.getValue("Email"));
_pkcs = pkcs;
@@ -180,10 +180,10 @@ KSSLX509Map mcert(name);
TQString tmp;
setText(0, mcert.getValue("O"));
tmp = mcert.getValue("OU");
- tmp.replace("\n", ", ");
+ tmp.tqreplace("\n", ", ");
setText(1, tmp);
tmp = mcert.getValue("CN");
- tmp.replace("\n", ", ");
+ tmp.tqreplace("\n", ", ");
setText(2, tmp);
_name = name;
_cert = cert;
@@ -269,7 +269,7 @@ TQString whatstr;
grid->addWidget(mUseTLS, 0, 0);
whatstr = i18n("TLS is the newest revision of the SSL protocol."
" It integrates better with other protocols and has"
- " replaced SSL in protocols such as POP3 and SMTP.");
+ " tqreplaced SSL in protocols such as POP3 and SMTP.");
TQWhatsThis::add(mUseTLS, whatstr);
mUseSSLv2 = new TQCheckBox(i18n("Enable SSLv&2"), tabSSL);
@@ -842,7 +842,7 @@ TQString whatstr;
tabs->addTab(tabSSLCOpts, i18n("Validation Options"));
#endif
- tabs->resize(tabs->sizeHint());
+ tabs->resize(tabs->tqsizeHint());
load();
}
@@ -1214,7 +1214,7 @@ void KCryptoConfig::save()
pcerts->sync();
authcfg->sync();
// insure proper permissions -- contains sensitive data
TQString cfgName(KGlobal::dirs()->findResource("config", "cryptodefaults"));
if (!cfgName.isEmpty())
::chmod(TQFile::encodeName(cfgName), 0600);
@@ -1480,7 +1480,7 @@ TQString iss = TQString::null;
TQPalette cspl;
iss = cert->getIssuer();
cspl = validFrom->palette();
- if (TQDateTime::currentDateTime(Qt::UTC) < cert->getQDTNotBefore()) {
+ if (TQDateTime::tqcurrentDateTime(Qt::UTC) < cert->getQDTNotBefore()) {
cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
} else {
cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
@@ -1488,7 +1488,7 @@ TQString iss = TQString::null;
validFrom->setPalette(cspl);
cspl = validUntil->palette();
- if (TQDateTime::currentDateTime(Qt::UTC) > cert->getQDTNotAfter()) {
+ if (TQDateTime::tqcurrentDateTime(Qt::UTC) > cert->getQDTNotAfter()) {
cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
} else {
cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
@@ -1498,7 +1498,7 @@ TQString iss = TQString::null;
validFrom->setText(cert->getNotBefore());
validUntil->setText(cert->getNotAfter());
untilDate->setText(x ? KGlobal::locale()->formatDateTime(x->getExpires())
- : KGlobal::locale()->formatDateTime(TQDateTime::currentDateTime(Qt::UTC)));
+ : KGlobal::locale()->formatDateTime(TQDateTime::tqcurrentDateTime(Qt::UTC)));
untilDate->setEnabled(x && !x->isPermanent());
pHash->setText(cert->getMD5DigestText());
delete cert;
@@ -1587,7 +1587,7 @@ TryImportPassAgain:
i;
i = static_cast<YourCertItem *>(i->nextSibling())) {
if (i->configName() == name) {
- rc = KMessageBox::warningContinueCancel(this, i18n("A certificate with that name already exists. Are you sure that you wish to replace it?"), i18n("SSL"), i18n("Replace"));
+ rc = KMessageBox::warningContinueCancel(this, i18n("A certificate with that name already exists. Are you sure that you wish to tqreplace it?"), i18n("SSL"), i18n("Replace"));
if (rc == KMessageBox::Cancel) {
delete cert;
return;
@@ -1718,7 +1718,7 @@ TQString iss;
TQPalette cspl;
KSSLCertificate *cert = pkcs->getCertificate();
cspl = yValidFrom->palette();
- if (TQDateTime::currentDateTime(Qt::UTC) < cert->getQDTNotBefore()) {
+ if (TQDateTime::tqcurrentDateTime(Qt::UTC) < cert->getQDTNotBefore()) {
cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
} else {
cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
@@ -1726,7 +1726,7 @@ TQString iss;
yValidFrom->setPalette(cspl);
cspl = yValidUntil->palette();
- if (TQDateTime::currentDateTime(Qt::UTC) > cert->getQDTNotAfter()) {
+ if (TQDateTime::tqcurrentDateTime(Qt::UTC) > cert->getQDTNotAfter()) {
cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
} else {
cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
@@ -1758,7 +1758,7 @@ TQString iss;
KSSLCertificate *cert = pkcs->getCertificate();
iss = cert->getIssuer();
cspl = yValidFrom->palette();
- if (TQDateTime::currentDateTime(Qt::UTC) < cert->getQDTNotBefore()) {
+ if (TQDateTime::tqcurrentDateTime(Qt::UTC) < cert->getQDTNotBefore()) {
cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
} else {
cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
@@ -1766,7 +1766,7 @@ TQString iss;
yValidFrom->setPalette(cspl);
cspl = yValidUntil->palette();
- if (TQDateTime::currentDateTime(Qt::UTC) > cert->getQDTNotAfter()) {
+ if (TQDateTime::tqcurrentDateTime(Qt::UTC) > cert->getQDTNotAfter()) {
cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
} else {
cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
@@ -1921,7 +1921,7 @@ void KCryptoConfig::slotCAImport() {
if (certStore) { KOSSL::self()->X509_STORE_free(certStore);
certStore = NULL; }
- if (certtext.contains("-----BEGIN CERTIFICATE-----")) {
+ if (certtext.tqcontains("-----BEGIN CERTIFICATE-----")) {
qf.reset();
certtext = TQString::null;
while (!qf.atEnd()) {
@@ -1929,10 +1929,10 @@ void KCryptoConfig::slotCAImport() {
qf.readLine(xx, qf.size());
certtext += xx;
}
- certtext = certtext.replace("-----BEGIN CERTIFICATE-----", TQString::null);
- certtext = certtext.replace("-----END CERTIFICATE-----", TQString::null);
+ certtext = certtext.tqreplace("-----BEGIN CERTIFICATE-----", TQString::null);
+ certtext = certtext.tqreplace("-----END CERTIFICATE-----", TQString::null);
certtext = certtext.stripWhiteSpace();
- certtext = certtext.replace("\n", TQString::null);
+ certtext = certtext.tqreplace("\n", TQString::null);
} else {
// Must [could?] be DER
qf.close();
@@ -2350,7 +2350,7 @@ SSL_CONST SSL_METHOD *meth;
break;
// Leak of sc*?
TQString scn(sc->name);
- if (scn.contains("ADH-") || scn.contains("NULL-") || scn.contains("DES-CBC3-SHA") || scn.contains("FZA-")) {
+ if (scn.tqcontains("ADH-") || scn.tqcontains("NULL-") || scn.tqcontains("DES-CBC3-SHA") || scn.tqcontains("FZA-")) {
continue;
}
k = SSL_CIPHER_get_bits(sc, &j);
@@ -2378,7 +2378,7 @@ SSL_CONST SSL_METHOD *meth;
break;
// Leak of sc*?
TQString scn(sc->name);
- if (scn.contains("ADH-") || scn.contains("NULL-") || scn.contains("DES-CBC3-SHA") || scn.contains("FZA-")) {
+ if (scn.tqcontains("ADH-") || scn.tqcontains("NULL-") || scn.tqcontains("DES-CBC3-SHA") || scn.tqcontains("FZA-")) {
continue;
}
k = SSL_CIPHER_get_bits(sc, &j);
@@ -1214,7 +1214,7 @@ void KCryptoConfig::save()
pcerts->sync();
authcfg->sync();
- // insure proper permissions -- contains sensitive data
+ // insure proper permissions -- tqcontains sensitive data
TQString cfgName(KGlobal::dirs()->findResource("config", "cryptodefaults"));
if (!cfgName.isEmpty())